//
//
// Wireless-mouse modification project by OM2JU
// Part: Main shell
//
//
//------------------------------------------------------------------------------------------
$fn = 64;    // Rounding parameter; for production set to high (e.g. 64) 
//
//----------------------------------------------------------------------------------
//
// Rounded primitives for openscad
// (c) 2013 Wouter Robers 

// Syntax example for a rounded block
//translate([-15,0,10]) rcube([20,20,20],2);

// Syntax example for a rounded cylinder
//translate([15,0,10]) rcylinder(r1=15,r2=10,h=20,b=2);

module rcube(Size=[20,20,20],b=2)
{hull(){for(x=[-(Size[0]/2-b),(Size[0]/2-b)]){for(y=[-(Size[1]/2-b),(Size[1]/2-b)]){for(z=[-(Size[2]/2-b),(Size[2]/2-b)]){ translate([x,y,z]) sphere(b);}}}}}


module rcylinder(r1=10,r2=10,h=10,b=2)
{translate([0,0,-h/2]) hull(){rotate_extrude() translate([r1-b,b,0]) circle(r = b); rotate_extrude() translate([r2-b, h-b, 0]) circle(r = b);}}
    
//----------------------------------------------------------------------------------

difference() {
// difference of two rounded cubes, creates shell like object
translate([0,0,30/2])   rcube(Size=[61+3,81+3,30],b=9.0);
translate([0,0,50/2+2]) rcube(Size=[61,  81,  50],b=9.0);  

// big cube from top to limit height
translate([0,0,150/2+20]) cube(size=[150,150,150],center=true);  

// round circle opening in the middle
translate([0,0,-5]) linear_extrude (height = 10) { circle(d=19-5); }


// cut from inside as guide for base plate which will be inserted
translate([0,0,20-2])   cube(size=[60+2,80-7,2],center=true);

// opening for pushbuttons
translate([19, 32.1,-5]) linear_extrude (height = 10) { circle(d=4.7); }
translate([-19,32.1,-5]) linear_extrude (height = 10) { circle(d=4.7); }


rotate([0,180,0])
translate([ -23.3,-31.5,4.0]) linear_extrude (height=10, center = true) text("OM2JU.com", size=6.4, font="Courier:style=Bold");

}


// Holder bars for D2F switches
difference() {
  union () {
  translate([ 0,36,7])     cube(size=[49,2,11],center=true);
  translate([ 0,34-5.8,7]) cube(size=[49,2,11],center=true);      
  }
  // holes for D2F #1
  rotate([90,0,0]) translate([20.5,3+7,-38]) linear_extrude(height = 12) { circle(d=2);}
  rotate([90,0,0]) translate([20.5-6.5,3+7,-38]) linear_extrude(height = 12) { circle(d=2);}
  // holes for D2F #2
  rotate([90,0,0]) translate([-20.5,3+7,-38]) linear_extrude(height = 12) { circle(d=2);}
  rotate([90,0,0]) translate([-20.5+6.5,3+7,-38]) linear_extrude(height = 12) { circle(d=2);}

}

// Holder for bearing
union () {
difference() {
 translate([0,0,8.5]) linear_extrude (height = 1.5) { circle(d=19.4+4.4); }
 translate([0,0,7])   linear_extrude (height = 4)   { circle(d=11); }
}
//
difference() {
 translate([0,0,2]) linear_extrude (height = 6.5) { circle(d=19.4+4.4); }
 translate([0,0,2]) linear_extrude (height = 8.5) { circle(d=19.4); } 
//opening from side to insert bearing
 translate([0,10,2]) cube(size=[20-1,20,20],center=true);  
}
} // end union 

// holder for encoder
translate([-6.3,-3,10+6/2]) cube(size=[3,12,6],center=true); 
translate([ 6.3,-3,10+6/2]) cube(size=[3,12,6],center=true); 

// Holder for AA battery (AA battery has length of 50mm)
// AA battery holder - end +
difference() {
 translate([ 20,  -16-13.0-4.5,13/2+2.2])   cube(size=[15,6,13],center=true); 
 translate([ 20,  -16-13.0-4.5+2,14/2+2.2]) cube(size=[13,0.5,15],center=true); 

 translate([ 17,  -16-13.0-4.75+2+1,14/2+8]) cube(size=[13,2,5],center=true); 

 translate([ 20,  -16-13.0-4.5+4,14/2+2.2]) cube(size=[10,4,15],center=true); 
 translate([ 17.5,-16-13.0-4.5-3.2,17]) linear_extrude (height=5, center = true) text("+", size=5.5, font="Courier:style=Bold");

}

translate([ 24,26,8/2+2]) cube(size=[2,6,8],center=true); 
translate([ 18,26,8/2+2]) cube(size=[2,6,8],center=true); 

translate([ 24,-38.2,8/2+6]) cube(size=[2,6,8],center=true); 
translate([ 18,-38.2,8/2+6]) cube(size=[2,6,8],center=true); 


// AA battery holder - end -
difference() {
 translate([ 20,  -16+38.0,13/2+2.2])   cube(size=[15,6,13],center=true); 
 translate([ 20,  -16+38.0-2,14/2+2.2]) cube(size=[13,0.5,15],center=true); 

 rotate([90,0,0]) translate([21,3+7,-32]) linear_extrude(height = 22) { circle(d=4);}

 translate([ 17,  -16+38.0-2-0.75,14/2+7]) cube(size=[13,2,5],center=true); 

 translate([ 20,  -16+38.0-4,14/2+2.2]) cube(size=[10,4,15],center=true); 
 translate([ 17.5,-16+38.0-1.8,17]) linear_extrude (height=5, center = true) text("-", size=7.0, font="Courier:style=Bold");

}
